@@ -1,3 +1,5 @@
+#' @export
+#' @method print PCAmix
 print.PCAmix <- function(x, ...){
   if (!inherits(x, "PCAmix")) 
     stop("use only with \"PCAmix\" objects")
@@ -24,7 +26,7 @@ print.PCAmix <- function(x, ...){
     res[6,] <- c("$sqload", "squared loadings after rotation")    
     res[7,] <- c("$coef", "coef of the linear combinations defining the rotated PC")
     res[8,] <- c("$theta", "angle of rotation if 'dim'=2")
-    res[9,] <- c("$T", "matrix of rotation if 'dim'=2")
+    res[9,] <- c("$T", "matrix of rotation")
   } else {
     res <- matrix("",7,2)
     colnames(res) <-c("name","description")
@@ -32,9 +34,17 @@ print.PCAmix <- function(x, ...){
     res[2,] <- c("$ind", "results for the individuals (coord,contrib,cos2)")
     res[3,] <- c("$quanti", "results for the quantitative variables (coord,contrib,cos2)")
     res[4,] <- c("$levels", "results for the levels of the qualitative variables (coord,contrib,cos2)")
-    res[5,] <- c("$quali", "results for the qualitative variables (coord,contrib,cos2)")
+    res[5,] <- c("$quali", "results for the qualitative variables (contrib,relative contrib)")
     res[6,] <- c("$sqload", "squared loadings")
     res[7,] <- c("$coef", "coef of the linear combinations defining the PC")
   }
+  if (!(is.null(x$sqload.sup)))
+  {
+    sup <- matrix("",3,2)
+    sup[1,] <- c("$quanti.sup", "results for the supplementary quantitative variables")
+    sup[2,] <- c("$levels.sup", "results for the levels of the qualitative variables")
+    sup[3,] <- c("$sqload.sup", "squared loadings of the supplementary variables")
+    res <- rbind(res,sup)
+  }
   print(res)
 }
\ No newline at end of file
